import React from 'react';
import styles from './ChartDetail.module.scss';
import { useChart } from '../../../../swr/chart';
import Loader from '../../../../components/page-content/loader/Loader';
import EditChartModal from '../edit-chart-modal/EditChartModal';

interface Props {
  chartId: string;
}

const ChartDetail = (props: Props): JSX.Element => {
  const { chartId } = props;
  const { chart, isLoading, error } = useChart(chartId);

  if (isLoading) {
    return <Loader hasStartedLoading={true} isLoading={true} />;
  }

  if (error) {
    return <div>{JSON.stringify(error)}</div>;
  }

  return (
    <div className={styles.chartList}>
      <div className={styles.header}>
        <h1>Charts</h1>
        <EditChartModal chart={chart} />
      </div>
      <hr />
      <pre>{JSON.stringify(chart, null, 2)}</pre>
    </div>
  );
};

export default ChartDetail;
